@@ -43,8 +43,8 @@ fn generate_keys_py() -> (String, String) {
     let private_key = keypair.private().to_vec();
     let public_key = keypair.public().to_vec();
 
-    let private_encoded = base64::encode_config(private_key, base64::URL_SAFE);
-    let public_encoded = base64::encode_config(public_key, base64::URL_SAFE);
+    let private_encoded = base64::encode_config(private_key, base64::URL_SAFE_NO_PAD);
+    let public_encoded = base64::encode_config(public_key, base64::URL_SAFE_NO_PAD);
 
     (private_encoded, public_encoded)
 }
@@ -73,11 +73,11 @@ impl ToPyErr for DecodeError {
 
 #[pyfunction]
 fn register_server_py(client_request: String, public_key: String) -> PyResult<(String, String)> {
-    let request_bytes = base64::decode_config(client_request, base64::URL_SAFE)
+    let request_bytes = base64::decode_config(client_request, base64::URL_SAFE_NO_PAD)
         .map_err(ToPyErr::to_pyerr)?;
     let client_request: RegistrationRequest<DefaultCipher> = RegistrationRequest::deserialize(&request_bytes)
         .map_err(ToPyErr::to_pyerr)?;
-    let key_bytes = base64::decode_config(public_key, base64::URL_SAFE)
+    let key_bytes = base64::decode_config(public_key, base64::URL_SAFE_NO_PAD)
         .map_err(ToPyErr::to_pyerr)?;
     let public_key = Key::from_bytes(&key_bytes)
         .map_err(ToPyErr::to_pyerr)?;
@@ -88,20 +88,20 @@ fn register_server_py(client_request: String, public_key: String) -> PyResult<(S
     let response_bytes = s.message.serialize();
     let state_bytes = s.state.serialize();
 
-    let response_encoded = base64::encode_config(response_bytes, base64::URL_SAFE);
-    let state_encoded = base64::encode_config(state_bytes, base64::URL_SAFE);
+    let response_encoded = base64::encode_config(response_bytes, base64::URL_SAFE_NO_PAD);
+    let state_encoded = base64::encode_config(state_bytes, base64::URL_SAFE_NO_PAD);
 
     Ok((response_encoded, state_encoded))
 }
 
 #[pyfunction]
 fn register_server_finish_py(client_request_finish: String, registration_state: String) -> PyResult<String> {
-    let request_bytes = base64::decode_config(client_request_finish, base64::URL_SAFE)
+    let request_bytes = base64::decode_config(client_request_finish, base64::URL_SAFE_NO_PAD)
         .map_err(ToPyErr::to_pyerr)?;
     let client_request_finish: RegistrationUpload<DefaultCipher> = RegistrationUpload::deserialize(&request_bytes)
         .map_err(ToPyErr::to_pyerr)?;
 
-    let state_bytes = base64::decode_config(registration_state, base64::URL_SAFE)
+    let state_bytes = base64::decode_config(registration_state, base64::URL_SAFE_NO_PAD)
         .map_err(ToPyErr::to_pyerr)?;
     let registration_state: ServerRegistration<DefaultCipher> = ServerRegistration::deserialize(&state_bytes)
         .map_err(ToPyErr::to_pyerr)?;
@@ -111,24 +111,24 @@ fn register_server_finish_py(client_request_finish: String, registration_state:
 
     let password_file_bytes = s.serialize();
 
-    let password_file_encoded = base64::encode_config(password_file_bytes, base64::URL_SAFE);
+    let password_file_encoded = base64::encode_config(password_file_bytes, base64::URL_SAFE_NO_PAD);
 
     Ok(password_file_encoded)
 }
 
 #[pyfunction]
 fn login_server_py(password_file: String, client_request: String, private_key: String) -> PyResult<(String, String)> {
-    let password_file_bytes = base64::decode_config(password_file, base64::URL_SAFE)
+    let password_file_bytes = base64::decode_config(password_file, base64::URL_SAFE_NO_PAD)
         .map_err(ToPyErr::to_pyerr)?;
     let password_file= ServerRegistration::<DefaultCipher>::deserialize(&password_file_bytes)
         .map_err(ToPyErr::to_pyerr)?;
 
-    let request_bytes = base64::decode_config(client_request, base64::URL_SAFE)
+    let request_bytes = base64::decode_config(client_request, base64::URL_SAFE_NO_PAD)
         .map_err(ToPyErr::to_pyerr)?;
     let client_request: CredentialRequest<DefaultCipher> = CredentialRequest::deserialize(&request_bytes)
         .map_err(ToPyErr::to_pyerr)?;
 
-    let key_bytes = base64::decode_config(private_key, base64::URL_SAFE)
+    let key_bytes = base64::decode_config(private_key, base64::URL_SAFE_NO_PAD)
         .map_err(ToPyErr::to_pyerr)?;
     let private_key = Key::from_bytes(&key_bytes)
         .map_err(ToPyErr::to_pyerr)?;
@@ -141,20 +141,20 @@ fn login_server_py(password_file: String, client_request: String, private_key: S
     let state_bytes = s.state.serialize()
         .map_err(ToPyErr::to_pyerr)?;
 
-    let response_encoded = base64::encode_config(response_bytes, base64::URL_SAFE);
-    let state_encoded = base64::encode_config(state_bytes, base64::URL_SAFE);
+    let response_encoded = base64::encode_config(response_bytes, base64::URL_SAFE_NO_PAD);
+    let state_encoded = base64::encode_config(state_bytes, base64::URL_SAFE_NO_PAD);
 
     Ok((response_encoded, state_encoded))
 }
 
 #[pyfunction]
 fn login_server_finish_py(client_request_finish: String, login_state: String) -> PyResult<String> {
-    let request_bytes = base64::decode_config(client_request_finish, base64::URL_SAFE)
+    let request_bytes = base64::decode_config(client_request_finish, base64::URL_SAFE_NO_PAD)
         .map_err(ToPyErr::to_pyerr)?;
     let client_request_finish: CredentialFinalization<DefaultCipher> = CredentialFinalization::deserialize(&request_bytes)
         .map_err(ToPyErr::to_pyerr)?;
 
-    let state_bytes = base64::decode_config(login_state, base64::URL_SAFE)
+    let state_bytes = base64::decode_config(login_state, base64::URL_SAFE_NO_PAD)
         .map_err(ToPyErr::to_pyerr)?;
     let login_state: ServerLogin<DefaultCipher> = ServerLogin::deserialize(&state_bytes)
         .map_err(ToPyErr::to_pyerr)?;
@@ -164,7 +164,7 @@ fn login_server_finish_py(client_request_finish: String, login_state: String) ->
 
     let session_key_bytes = s.session_key;
 
-    let session_key_encoded = base64::encode_config(session_key_bytes, base64::URL_SAFE);
+    let session_key_encoded = base64::encode_config(session_key_bytes, base64::URL_SAFE_NO_PAD);
 
     Ok(session_key_encoded)
 }
@@ -224,8 +224,8 @@ mod tests {
     #[test]
     fn server_register() {
         // let x = generate();
-        // let pub_string = base64::encode_config(x.public().as_slice(), base64::URL_SAFE);
-        // let priv_string = base64::encode_config(x.private().as_slice(), base64::URL_SAFE);
+        // let pub_string = base64::encode_config(x.public().as_slice(), base64::URL_SAFE_NO_PAD);
+        // let priv_string = base64::encode_config(x.private().as_slice(), base64::URL_SAFE_NO_PAD);
         // println!("{}", pub_string);
         // println!("{}", priv_string);
 
